@@ -6,7 +6,7 @@ Chisel is a light-weight Python WSGI application framework with tools for buildi
 well-tested, schema-validated JSON web APIs.
 """
 
-__version__ = '0.9.99'
+__version__ = '0.9.101'
 
 from .action import \
     Action, \
@@ -20,43 +20,19 @@ from .app import \
 from .doc import \
     create_doc_requests
 
-from .model import \
-    ActionModel, \
-    AttributeValidationError, \
-    EnumValue, \
-    StructMember, \
-    StructMemberAttributes, \
-    TYPE_BOOL, \
-    TYPE_DATE, \
-    TYPE_DATETIME, \
-    TYPE_FLOAT, \
-    TYPE_INT, \
-    TYPE_OBJECT, \
-    TYPE_STRING, \
-    TYPE_UUID, \
-    TypeArray, \
-    TypeBool, \
-    TypeDate, \
-    TypeDatetime, \
-    TypeDict, \
-    TypeEnum, \
-    TypeFloat, \
-    TypeInt, \
-    TypeObject, \
-    TypeString, \
-    TypeStruct, \
-    TypeUuid, \
-    Typedef, \
-    ValidationError, \
-    ValidationMode, \
-    get_referenced_types
-
 from .request import \
     RedirectRequest, \
     Request, \
     StaticRequest, \
     request
 
+from .schema import \
+    ValidationError, \
+    get_referenced_types, \
+    get_type_model, \
+    validate_types, \
+    validate_type
+
 from .spec import \
     SpecParser, \
     SpecParserError
