@@ -284,11 +284,9 @@ class Context:
         """
         Add a header key/value to the request's response
 
-        >>> import chisel
-        ...
         >>> @chisel.action(spec='''
         ... action my_action
-        ...     url
+        ...     urls
         ...         GET
         ... ''')
         ... def my_action(ctx, req):
@@ -315,11 +313,10 @@ class Context:
 
         >>> from datetime import datetime
         >>> from pprint import pprint
-        >>> import chisel
         ...
         >>> @chisel.action(spec='''
         ... action my_action
-        ...     url
+        ...     urls
         ...         GET
         ... ''')
         ... def my_action(ctx, req):
@@ -358,11 +355,10 @@ class Context:
         A generic WSGI response
 
         >>> from http import HTTPStatus
-        >>> import chisel
         ...
         >>> @chisel.action(wsgi_response=True, spec='''
         ... action my_action
-        ...     url
+        ...     urls
         ...         GET
         ... ''')
         ... def my_action(ctx, req):
@@ -393,11 +389,10 @@ class Context:
         A plain-text WSGI response
 
         >>> from http import HTTPStatus
-        >>> import chisel
         ...
         >>> @chisel.action(wsgi_response=True, spec='''
         ... action my_action
-        ...     url
+        ...     urls
         ...         GET
         ... ''')
         ... def my_action(ctx, req):
@@ -428,11 +423,10 @@ class Context:
         A JSON response
 
         >>> from http import HTTPStatus
-        >>> import chisel
         ...
         >>> @chisel.action(wsgi_response=True, spec='''
         ... action my_action
-        ...     url
+        ...     urls
         ...         GET
         ... ''')
         ... def my_action(ctx, req):
@@ -470,7 +464,6 @@ class Context:
         """
         Reconstruct the request's URL
 
-        >>> import chisel
         >>> application = chisel.Application()
         >>> ctx = chisel.Context(application, chisel.Context.create_environ('GET', '/hello'))
         >>> ctx.reconstruct_url()
